@@ -89,10 +89,11 @@ class navigatorConfig(metaclass=Singleton):
         # get the current environment
         environment = os.getenv('ENV', '')
         self.ENV = environment
-        # getting type of enviroment consummer:
+        # getting type of enviroment consumer:
         env_type = os.getenv('NAVCONFIG_ENV', 'file') # file by default
         # get the environment
         try:
+            logging.debug(f':: Environment type: {env_type}, ENV={environment}')
             self.load_enviroment(env_type)
         except FileNotFoundError:
             logging.error('Environment File Missing, using current env + INI file.')
@@ -101,14 +102,15 @@ class navigatorConfig(metaclass=Singleton):
         self._ini = ConfigParser()
         #self._ini = RawConfigParser()
         cf = Path(config_file).resolve()
+        logging.debug(f':: Config INI File: {cf!s}')
         if not cf.exists():
             cf = site_root.joinpath('etc', self._conffile)
         try:
             #with open(cf) as f:
             self._ini.read(cf)
-        except IOError:
-            print(cf, "INI file does not exist!")
-            raise IOError("INI file does not exist!")
+        except (IOError, Exception) as err:
+            print(cf, f"INI file does not exist: {err}")
+            raise IOError(f"INI file does not exist: {err}")
             return None
         # define debug
         self._debug = os.getenv('DEBUG', False)
@@ -149,6 +151,7 @@ class navigatorConfig(metaclass=Singleton):
     def load_enviroment(self, env_type: str = 'file'):
         if env_type == 'file':
             env_path = self.site_root.joinpath('env', self.ENV, '.env')
+            logging.debug(f'Environment File: {env_path!s}')
             # warning if env_path is an empty file or doesnt exists
             if env_path.exists():
                 if os.stat(str(env_path)).st_size == 0:
@@ -195,89 +198,66 @@ class navigatorConfig(metaclass=Singleton):
         else:
             raise Exception('Failed to load ENV file')
 
-    def getboolean(self, value, section=None, fallback=None):
+    def getboolean(self, key, section=None, fallback=None):
         """
         getboolean.
             Interface for getboolean function of ini parser
         """
         val = None
-        # get ENV value
-        if value in os.environ:
-            val = os.getenv(value, fallback)
-            if val:
-                if val.lower() in self._ini.BOOLEAN_STATES: # Check inf val is Boolean
-                    return self._ini.BOOLEAN_STATES[val.lower()]
-                else:
-                    return bool(val)
-
         # if not val and if section, get from INI
-        if not val and section != None:
+        if section is not None:
             try:
-                val = self._ini.getboolean(section, value)
+                val = self._ini.getboolean(section, key)
+                return val
+            except ValueError:
+                val = self._ini.get(section, key)
                 if not val:
                     return fallback
                 else:
-                    return bool(val)
+                    return self._ini.BOOLEAN_STATES[val.lower()]
             except Exception:
                 return fallback
+        # get ENV value
+        if key in os.environ:
+            val = os.getenv(key, fallback)
 
-        # If not val and not section, get from MEMCACHED
-        if not val and section == None:
-             #TODO: change to a non-async MEMCACHED connector
-            val = self._mem.get(value)
+        if self._redis.exists(key):
+            val = self._redis.get(key)
 
-        # last: check if value exists on ini
-        for section in self._ini.sections():
-            try:
-                val = self._ini.get(section, value)
-                if val:
-                    if val.lower() in self._ini.BOOLEAN_STATES: # Check inf val is Boolean
-                        return self._ini.BOOLEAN_STATES[val.lower()]
-            except Exception:
-                continue
-        return fallback
+        if not val:
+            val = self._mem.get(key)
 
-    def getint(self, value, section=None, fallback=None):
+        if val:
+            if val.lower() in self._ini.BOOLEAN_STATES: # Check inf val is Boolean
+                return self._ini.BOOLEAN_STATES[val.lower()]
+            else:
+                return bool(val)
+        else:
+            return fallback
+
+    def getint(self, key, section=None, fallback=None):
         """
         getint.
             Interface for getint function of ini parser
         """
         val = None
-        # get ENV value
-        if value in os.environ:
-            val = os.getenv(value, fallback)
-            if val:
-                return int(val)
-
-        # if not val and if section, get from INI
-        if not val and section is not None:
+        if section is not None:
             try:
-                val = self._ini.getint(section, value)
-                if not val:
-                    return fallback
-                else:
-                    return int(val)
+                val = self._ini.getint(section, key)
+            except Exception:
+                pass
+        if key in os.environ:
+            val = os.getenv(key, fallback)
+        if self._redis.exists(key):
+            val = self._redis.get(key)
+        if not val:
+            return fallback
+        if val.isdigit(): # Check if val is Integer
+            try:
+                return int(val)
             except Exception:
                 return fallback
 
-        # If not val and not section, get from MEMCACHED
-        if not val and section is None:
-            # TODO: change to a non-async MEMCACHED connector
-            val = self._mem.get(value)
-            if val:
-                return int(val)
-
-        # last: check if value exists on ini
-        for section in self._ini.sections():
-            try:
-                val = self._ini.get(section, value)
-                if val:
-                    if val.isdigit(): # Check if val is Integer
-                        return int(val)
-            except Exception:
-                continue
-        return fallback
-
     def getlist(self, key, section=None, fallback: list = None):
         """
         getlist.
@@ -289,6 +269,15 @@ class navigatorConfig(metaclass=Singleton):
                 val = self._ini.get(section, key)
             except Exception:
                 pass
+        if key in os.environ:
+            val = os.getenv(key, fallback)
+        if self._redis.exists(key):
+            val = self._redis.get(key)
+        if val:
+            return val.split(',')
+        else:
+            return []
+
 
     def get(self, key, section=None, fallback=None):
         """
@@ -300,19 +289,18 @@ class navigatorConfig(metaclass=Singleton):
         if section is not None:
             try:
                 val = self._ini.get(section, key)
+                return val
             except Exception:
                 pass
         # get ENV value
         if key in os.environ:
             val = os.getenv(key, fallback)
-            if val:
-                return val
+            return val
         # if not in os.environ, got from Redis
-        if not val and section is None:
-            if self._redis.exists(key):
-                return self._redis.get(key)
+        if self._redis.exists(key):
+            return self._redis.get(key)
         # If not in redis, get from MEMCACHED
-        if not val and section is None:
+        if not val:
             val = self._mem.get(key)
             if val:
                 return val
